@@ -2,15 +2,11 @@ from typing import Generator, Optional, Dict, List, Set, Union
 
 import logging
 import collections
-import numpy as np
+from pathlib import Path
 from itertools import islice
 from abc import abstractmethod
-from pathlib import Path
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal  # type: ignore
+import numpy as np
 
 from haystack.schema import Document, Label, MultiLabel
 from haystack.nodes.base import BaseComponent
@@ -281,6 +277,10 @@ class BaseDocumentStore(BaseComponent):
 
         all_labels = self.get_all_labels(index=index, filters=filters, headers=headers)
 
+        # drop no_answers in order to not create empty MultiLabels
+        if drop_no_answers:
+            all_labels = [label for label in all_labels if label.no_answer == False]
+
         grouped_labels: dict = {}
         for l in all_labels:
             # This group_keys determines the key by which we aggregate labels. Its contents depend on
@@ -372,11 +372,11 @@ class BaseDocumentStore(BaseComponent):
             if norm != 0.0:
                 vec /= norm
 
-    def finalize_raw_score(self, raw_score: float, similarity: Optional[str]) -> float:
+    def scale_to_unit_interval(self, score: float, similarity: Optional[str]) -> float:
         if similarity == "cosine":
-            return (raw_score + 1) / 2
+            return (score + 1) / 2
         else:
-            return float(expit(raw_score / 100))
+            return float(expit(score / 100))
 
     @abstractmethod
     def query_by_embedding(
@@ -387,6 +387,7 @@ class BaseDocumentStore(BaseComponent):
         index: Optional[str] = None,
         return_embedding: Optional[bool] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = True,
     ) -> List[Document]:
         pass
 
@@ -535,7 +536,13 @@ class BaseDocumentStore(BaseComponent):
     def _create_document_field_map(self) -> Dict:
         pass
 
-    def run(self, documents: List[dict], index: Optional[str] = None, headers: Optional[Dict[str, str]] = None, id_hash_keys: Optional[List[str]] = None):  # type: ignore
+    def run(  # type: ignore
+        self,
+        documents: List[Union[dict, Document]],
+        index: Optional[str] = None,
+        headers: Optional[Dict[str, str]] = None,
+        id_hash_keys: Optional[List[str]] = None,
+    ):
         """
         Run requests of document stores
 
@@ -551,7 +558,10 @@ class BaseDocumentStore(BaseComponent):
         """
 
         field_map = self._create_document_field_map()
-        doc_objects = [Document.from_dict(d, field_map=field_map, id_hash_keys=id_hash_keys) for d in documents]
+        doc_objects = [
+            Document.from_dict(d, field_map=field_map, id_hash_keys=id_hash_keys) if isinstance(d, dict) else d
+            for d in documents
+        ]
         self.write_documents(documents=doc_objects, index=index, headers=headers)
         return {}, "output_1"
 
@@ -662,6 +672,8 @@ class KeywordDocumentStore(BaseDocumentStore):
         custom_query: Optional[str] = None,
         index: Optional[str] = None,
         headers: Optional[Dict[str, str]] = None,
+        all_terms_must_match: bool = False,
+        scale_score: bool = True,
     ) -> List[Document]:
         """
         Scan through documents in DocumentStore and return a small number documents
@@ -736,6 +748,13 @@ class KeywordDocumentStore(BaseDocumentStore):
         :param custom_query: Custom query to be executed.
         :param index: The name of the index in the DocumentStore from which to retrieve documents
         :param headers: Custom HTTP headers to pass to document store client if supported (e.g. {'Authorization': 'Basic YWRtaW46cm9vdA=='} for basic authentication)
+        :param all_terms_must_match: Whether all terms of the query must match the document.
+                                     If true all query terms must be present in a document in order to be retrieved (i.e the AND operator is being used implicitly between query terms: "cozy fish restaurant" -> "cozy AND fish AND restaurant").
+                                     Otherwise at least one query term must be present in a document in order to be retrieved (i.e the OR operator is being used implicitly between query terms: "cozy fish restaurant" -> "cozy OR fish OR restaurant").
+                                     Defaults to False.
+        :param scale_score: Whether to scale the similarity score to the unit interval (range of [0,1]).
+                            If true (default) similarity scores (e.g. cosine or dot_product) which naturally have a different value range will be scaled to a range of [0,1], where 1 means extremely relevant.
+                            Otherwise raw similarity scores (e.g. cosine or dot_product) will be used.
         """
 
 
