@@ -1,17 +1,15 @@
 from typing import TYPE_CHECKING, Any, Union, List, Optional, Dict, Generator
 
-if TYPE_CHECKING:
-    from haystack.nodes.retriever import BaseRetriever
-
 import json
 import logging
 import warnings
-import numpy as np
-from copy import deepcopy
 from pathlib import Path
-from tqdm.auto import tqdm
+from copy import deepcopy
 from inspect import Signature, signature
 
+import numpy as np
+from tqdm.auto import tqdm
+
 try:
     import faiss
     from haystack.document_stores.sql import (
@@ -25,6 +23,9 @@ except (ImportError, ModuleNotFoundError) as ie:
 from haystack.schema import Document
 from haystack.document_stores.base import get_batches_from_generator
 
+if TYPE_CHECKING:
+    from haystack.nodes.retriever import BaseRetriever
+
 
 logger = logging.getLogger(__name__)
 
@@ -56,7 +57,9 @@ class FAISSDocumentStore(SQLDocumentStore):
         faiss_index_path: Union[str, Path] = None,
         faiss_config_path: Union[str, Path] = None,
         isolation_level: str = None,
-        **kwargs,
+        n_links: int = 64,
+        ef_search: int = 20,
+        ef_construction: int = 80,
     ):
         """
         :param sql_url: SQL connection URL for database. It defaults to local file based SQLite DB. For large scale
@@ -101,12 +104,15 @@ class FAISSDocumentStore(SQLDocumentStore):
         :param faiss_config_path: Stored FAISS initial configuration parameters.
             Can be created via calling `save()`
         :param isolation_level: see SQLAlchemy's `isolation_level` parameter for `create_engine()` (https://docs.sqlalchemy.org/en/14/core/engines.html#sqlalchemy.create_engine.params.isolation_level)
+        :param n_links: used only if index_factory == "HNSW"
+        :param ef_search: used only if index_factory == "HNSW"
+        :param ef_construction: used only if index_factory == "HNSW"
         """
         # special case if we want to load an existing index from disk
         # load init params from disk and run init again
         if faiss_index_path is not None:
             sig = signature(self.__class__.__init__)
-            self._validate_params_load_from_disk(sig, locals(), kwargs)
+            self._validate_params_load_from_disk(sig, locals())
             init_params = self._load_init_params_from_config(faiss_index_path, faiss_config_path)
             self.__class__.__init__(self, **init_params)  # pylint: disable=non-parent-init-called
             return
@@ -140,7 +146,9 @@ class FAISSDocumentStore(SQLDocumentStore):
                 embedding_dim=self.embedding_dim,
                 index_factory=faiss_index_factory_str,
                 metric_type=self.metric_type,
-                **kwargs,
+                n_links=n_links,
+                ef_search=ef_search,
+                ef_construction=ef_construction,
             )
 
         self.return_embedding = return_embedding
@@ -154,8 +162,8 @@ class FAISSDocumentStore(SQLDocumentStore):
 
         self._validate_index_sync()
 
-    def _validate_params_load_from_disk(self, sig: Signature, locals: dict, kwargs: dict):
-        allowed_params = ["faiss_index_path", "faiss_config_path", "self", "kwargs"]
+    def _validate_params_load_from_disk(self, sig: Signature, locals: dict):
+        allowed_params = ["faiss_index_path", "faiss_config_path", "self"]
         invalid_param_set = False
 
         for param in sig.parameters.values():
@@ -163,7 +171,7 @@ class FAISSDocumentStore(SQLDocumentStore):
                 invalid_param_set = True
                 break
 
-        if invalid_param_set or len(kwargs) > 0:
+        if invalid_param_set:
             raise ValueError("if faiss_index_path is passed no other params besides faiss_config_path are allowed.")
 
     def _validate_index_sync(self):
@@ -172,20 +180,27 @@ class FAISSDocumentStore(SQLDocumentStore):
         # used when creating the original FAISS index
         if not self.get_document_count() == self.get_embedding_count():
             raise ValueError(
-                "The number of documents present in the SQL database does not "
-                "match the number of embeddings in FAISS. Make sure your FAISS "
+                f"The number of documents present in the SQL database ({self.get_document_count()}) does not "
+                f"match the number of embeddings in FAISS ({self.get_embedding_count()}). Make sure your FAISS "
                 "configuration file correctly points to the same database that "
                 "was used when creating the original index."
             )
 
-    def _create_new_index(self, embedding_dim: int, metric_type, index_factory: str = "Flat", **kwargs):
+    def _create_new_index(
+        self,
+        embedding_dim: int,
+        metric_type,
+        index_factory: str = "Flat",
+        n_links: int = 64,
+        ef_search: int = 20,
+        ef_construction: int = 80,
+    ):
         if index_factory == "HNSW":
             # faiss index factory doesn't give the same results for HNSW IP, therefore direct init.
             # defaults here are similar to DPR codebase (good accuracy, but very high RAM consumption)
-            n_links = kwargs.get("n_links", 64)
             index = faiss.IndexHNSWFlat(embedding_dim, n_links, metric_type)
-            index.hnsw.efSearch = kwargs.get("efSearch", 20)  # 20
-            index.hnsw.efConstruction = kwargs.get("efConstruction", 80)  # 80
+            index.hnsw.efSearch = ef_search
+            index.hnsw.efConstruction = ef_construction
             if "ivf" in index_factory.lower():  # enable reconstruction of vectors for inverted index
                 self.faiss_indexes[index].set_direct_map_type(faiss.DirectMap.Hashtable)
 
@@ -537,7 +552,9 @@ class FAISSDocumentStore(SQLDocumentStore):
                 f"Deletion of default index '{index}' detected. "
                 f"If you plan to use this index again, please reinstantiate '{self.__class__.__name__}' in order to avoid side-effects."
             )
-        del self.faiss_indexes[index]
+        if index in self.faiss_indexes:
+            del self.faiss_indexes[index]
+            logger.info(f"Index '{index}' deleted.")
         super().delete_index(index)
 
     def query_by_embedding(
@@ -548,6 +565,7 @@ class FAISSDocumentStore(SQLDocumentStore):
         index: Optional[str] = None,
         return_embedding: Optional[bool] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = True,
     ) -> List[Document]:
         """
         Find the document that is most similar to the provided `query_emb` by using a vector similarity metric.
@@ -558,6 +576,9 @@ class FAISSDocumentStore(SQLDocumentStore):
         :param top_k: How many documents to return
         :param index: Index name to query the document from.
         :param return_embedding: To return document embedding. Unlike other document stores, FAISS will return normalized embeddings
+        :param scale_score: Whether to scale the similarity score to the unit interval (range of [0,1]).
+                            If true (default) similarity scores (e.g. cosine or dot_product) which naturally have a different value range will be scaled to a range of [0,1], where 1 means extremely relevant.
+                            Otherwise raw similarity scores (e.g. cosine or dot_product) will be used.
         :return:
         """
         if headers:
@@ -588,8 +609,10 @@ class FAISSDocumentStore(SQLDocumentStore):
             str(v_id): s for v_id, s in zip(vector_id_matrix[0], score_matrix[0])
         }
         for doc in documents:
-            raw_score = scores_for_vector_ids[doc.meta["vector_id"]]
-            doc.score = self.finalize_raw_score(raw_score, self.similarity)
+            score = scores_for_vector_ids[doc.meta["vector_id"]]
+            if scale_score:
+                score = self.scale_to_unit_interval(score, self.similarity)
+            doc.score = score
 
             if return_embedding is True:
                 doc.embedding = self.faiss_indexes[index].reconstruct(int(doc.meta["vector_id"]))
