@@ -1,15 +1,12 @@
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union, Generator
 
-if TYPE_CHECKING:
-    from haystack.nodes.retriever import BaseRetriever
-
 import time
 import logging
-import numpy as np
-import torch
 from copy import deepcopy
 from collections import defaultdict
-from scipy.spatial.distance import cosine
+
+import numpy as np
+import torch
 from tqdm import tqdm
 
 from haystack.schema import Document, Label
@@ -17,9 +14,11 @@ from haystack.errors import DuplicateDocumentError
 from haystack.document_stores import BaseDocumentStore
 from haystack.document_stores.base import get_batches_from_generator
 from haystack.modeling.utils import initialize_device_settings
-
 from haystack.document_stores.filter_utils import LogicalFilterClause
 
+if TYPE_CHECKING:
+    from haystack.nodes.retriever import BaseRetriever
+
 logger = logging.getLogger(__name__)
 
 
@@ -285,6 +284,7 @@ class InMemoryDocumentStore(BaseDocumentStore):
         index: Optional[str] = None,
         return_embedding: Optional[bool] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = True,
     ) -> List[Document]:
         """
         Find the document that is most similar to the provided `query_emb` by using a vector similarity metric.
@@ -353,6 +353,9 @@ class InMemoryDocumentStore(BaseDocumentStore):
         :param top_k: How many documents to return
         :param index: Index name for storing the docs and metadata
         :param return_embedding: To return document embedding
+        :param scale_score: Whether to scale the similarity score to the unit interval (range of [0,1]).
+                            If true (default) similarity scores (e.g. cosine or dot_product) which naturally have a different value range will be scaled to a range of [0,1], where 1 means extremely relevant.
+                            Otherwise raw similarity scores (e.g. cosine or dot_product) will be used.
         :return:
         """
         if headers:
@@ -375,7 +378,9 @@ class InMemoryDocumentStore(BaseDocumentStore):
             new_document.embedding = doc.embedding if return_embedding is True else None
 
             new_document.embedding = doc.embedding if return_embedding is True else None
-            new_document.score = self.finalize_raw_score(score, self.similarity)
+            if scale_score:
+                score = self.scale_to_unit_interval(score, self.similarity)
+            new_document.score = score
             candidate_docs.append(new_document)
 
         return sorted(candidate_docs, key=lambda x: x.score if x.score is not None else 0.0, reverse=True)[0:top_k]
@@ -750,12 +755,9 @@ class InMemoryDocumentStore(BaseDocumentStore):
         :param index: The name of the index to delete.
         :return: None
         """
-        if index == self.index:
-            logger.warning(
-                f"Deletion of default index '{index}' detected. "
-                f"If you plan to use this index again, please reinstantiate '{self.__class__.__name__}' in order to avoid side-effects."
-            )
-        del self.indexes[index]
+        if index in self.indexes:
+            del self.indexes[index]
+            logger.info(f"Index '{index}' deleted.")
 
     def delete_labels(
         self,
