@@ -1,13 +1,9 @@
 from typing import TYPE_CHECKING, Any, Dict, Generator, List, Optional, Union
 
-if TYPE_CHECKING:
-    from haystack.nodes.retriever import BaseRetriever
-
 import logging
 import warnings
 import numpy as np
 from tqdm import tqdm
-from scipy.special import expit
 
 try:
     from milvus import IndexType, MetricType, Milvus, Status
@@ -20,6 +16,9 @@ except (ImportError, ModuleNotFoundError) as ie:
 from haystack.schema import Document
 from haystack.document_stores.base import get_batches_from_generator
 
+if TYPE_CHECKING:
+    from haystack.nodes.retriever import BaseRetriever
+
 
 logger = logging.getLogger(__name__)
 
@@ -61,9 +60,11 @@ class Milvus1DocumentStore(SQLDocumentStore):
         progress_bar: bool = True,
         duplicate_documents: str = "overwrite",
         isolation_level: str = None,
-        **kwargs,
     ):
         """
+        **WARNING:** Milvus1DocumentStore is deprecated and will be removed in a future version. Please switch to Milvus2
+        or consider using another DocumentStore.
+
         :param sql_url: SQL connection URL for storing document texts and metadata. It defaults to a local, file based SQLite DB. For large scale
                         deployment, Postgres is recommended. If using MySQL then same server can also be used for
                         Milvus metadata. For more details see https://milvus.io/docs/v1.0.0/data_manage.md.
@@ -107,7 +108,15 @@ class Milvus1DocumentStore(SQLDocumentStore):
                                     exists.
         :param isolation_level: see SQLAlchemy's `isolation_level` parameter for `create_engine()` (https://docs.sqlalchemy.org/en/14/core/engines.html#sqlalchemy.create_engine.params.isolation_level)
         """
-        super().__init__()
+        deprecation_message = (
+            "Milvus1DocumentStore is deprecated and will be removed in a future version. "
+            "Please consider switching to Milvus2 or to another DocumentStore."
+        )
+        warnings.warn(message=deprecation_message, category=FutureWarning, stacklevel=3)
+
+        super().__init__(
+            url=sql_url, index=index, duplicate_documents=duplicate_documents, isolation_level=isolation_level
+        )
 
         self.milvus_server = Milvus(uri=milvus_url, pool=connection_pool)
 
@@ -142,10 +151,6 @@ class Milvus1DocumentStore(SQLDocumentStore):
         self.embedding_field = embedding_field
         self.progress_bar = progress_bar
 
-        super().__init__(
-            url=sql_url, index=index, duplicate_documents=duplicate_documents, isolation_level=isolation_level
-        )
-
     def __del__(self):
         return self.milvus_server.close()
 
@@ -357,6 +362,7 @@ class Milvus1DocumentStore(SQLDocumentStore):
         index: Optional[str] = None,
         return_embedding: Optional[bool] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = True,
     ) -> List[Document]:
         """
         Find the document that is most similar to the provided `query_emb` by using a vector similarity metric.
@@ -367,6 +373,9 @@ class Milvus1DocumentStore(SQLDocumentStore):
         :param top_k: How many documents to return
         :param index: (SQL) index name for storing the docs and metadata
         :param return_embedding: To return document embedding
+        :param scale_score: Whether to scale the similarity score to the unit interval (range of [0,1]).
+                            If true (default) similarity scores (e.g. cosine or dot_product) which naturally have a different value range will be scaled to a range of [0,1], where 1 means extremely relevant.
+                            Otherwise raw similarity scores (e.g. cosine or dot_product) will be used.
         :return: list of Documents that are the most similar to `query_emb`
         """
         if headers:
@@ -410,8 +419,10 @@ class Milvus1DocumentStore(SQLDocumentStore):
             self._populate_embeddings_to_docs(index=index, docs=documents)
 
         for doc in documents:
-            raw_score = scores_for_vector_ids[doc.meta["vector_id"]]
-            doc.score = self.finalize_raw_score(raw_score, self.similarity)
+            score = scores_for_vector_ids[doc.meta["vector_id"]]
+            if scale_score:
+                score = self.scale_to_unit_interval(score, self.similarity)
+            doc.score = score
 
         return documents
 
