@@ -2,9 +2,10 @@ from typing import Any, Dict, Union, List, Optional, Generator
 
 import logging
 import itertools
-import numpy as np
 from uuid import uuid4
 
+import numpy as np
+
 try:
     from sqlalchemy import (
         and_,
@@ -13,7 +14,6 @@ try:
         Column,
         String,
         DateTime,
-        ForeignKey,
         Boolean,
         Text,
         text,
@@ -30,7 +30,6 @@ except (ImportError, ModuleNotFoundError) as ie:
 
 from haystack.schema import Document, Label, Answer
 from haystack.document_stores.base import BaseDocumentStore
-
 from haystack.document_stores.filter_utils import LogicalFilterClause
 
 
@@ -573,8 +572,8 @@ class SQLDocumentStore(BaseDocumentStore):
             id=row.id,
             no_answer=row.no_answer,
             pipeline_id=row.pipeline_id,
-            created_at=row.created_at,
-            updated_at=row.updated_at,
+            created_at=str(row.created_at),
+            updated_at=str(row.updated_at),
             meta=row.meta,
         )
         return label
@@ -587,6 +586,7 @@ class SQLDocumentStore(BaseDocumentStore):
         index: Optional[str] = None,
         return_embedding: Optional[bool] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = True,
     ) -> List[Document]:
 
         raise NotImplementedError(
@@ -665,7 +665,7 @@ class SQLDocumentStore(BaseDocumentStore):
         :param index: The name of the index to delete.
         :return: None
         """
-        self.delete_documents(index)
+        SQLDocumentStore.delete_documents(self, index)
 
     def delete_labels(
         self,
