@@ -2,14 +2,12 @@ from typing import List, Union
 
 
 class Question:
-    def __init__(self, text: str, uid: str=None):
+    def __init__(self, text: str, uid: str = None):
         self.text = text
         self.uid = uid
 
     def to_dict(self):
-        ret = {"question": self.text,
-               "id": self.uid,
-               "answers": []}
+        ret = {"question": self.text, "id": self.uid, "answers": []}
         return ret
 
 
@@ -19,11 +17,9 @@ class QAInput:
         if type(questions) == Question:
             self.questions = [questions]
         else:
-            self.questions = questions #type: ignore
+            self.questions = questions  # type: ignore
 
     def to_dict(self):
         questions = [q.to_dict() for q in self.questions]
-        ret = {"qas": questions,
-               "context": self.doc_text}
+        ret = {"qas": questions, "context": self.doc_text}
         return ret
-
