@@ -9,6 +9,9 @@ import torch
 from torch.nn import DataParallel
 from torch.nn.parallel import DistributedDataParallel
 
+from haystack.modeling.model.adaptive_model import AdaptiveModel
+from haystack.utils.experiment_tracking import Tracker as tracker
+
 logger = logging.getLogger(__name__)
 
 try:
@@ -35,10 +38,6 @@ except ImportError:
     logger.info("apex not found, won't use it. " "See https://nvidia.github.io/apex/")
 
 
-from haystack.modeling.model.adaptive_model import AdaptiveModel
-from haystack.modeling.logger import MLFlowLogger as MlLogger
-
-
 class WrappedDataParallel(DataParallel):
     """
     A way of adapting attributes of underlying class to parallel mode. See:
@@ -162,7 +161,7 @@ def initialize_optimizer(
         schedule_opts["num_training_steps"] = num_train_optimization_steps
 
     # Log params
-    MlLogger.log_params({"use_amp": use_amp, "num_train_optimization_steps": schedule_opts["num_training_steps"]})
+    tracker.track_params({"use_amp": use_amp, "num_train_optimization_steps": schedule_opts["num_training_steps"]})
 
     # Get optimizer from pytorch, transformers or apex
     optimizer = _get_optim(model, optimizer_opts)
@@ -190,8 +189,8 @@ def _get_optim(model, opts: Dict):
 
     # Logging
     logger.info(f"Loading optimizer `{optimizer_name}`: '{opts}'")
-    MlLogger.log_params(opts)
-    MlLogger.log_params({"optimizer_name": optimizer_name})
+    tracker.track_params(opts)
+    tracker.track_params({"optimizer_name": optimizer_name})
 
     weight_decay = opts.pop("weight_decay", None)
     no_decay = opts.pop("no_decay", None)
@@ -280,15 +279,15 @@ def get_scheduler(optimizer, opts):
     # convert from warmup proportion to steps if required
     if "num_warmup_steps" in allowed_args and "num_warmup_steps" not in opts and "warmup_proportion" in opts:
         opts["num_warmup_steps"] = int(opts["warmup_proportion"] * opts["num_training_steps"])
-        MlLogger.log_params({"warmup_proportion": opts["warmup_proportion"]})
+        tracker.track_params({"warmup_proportion": opts["warmup_proportion"]})
 
     # only pass args that are supported by the constructor
     constructor_opts = {k: v for k, v in opts.items() if k in allowed_args}
 
     # Logging
     logger.info(f"Loading schedule `{schedule_name}`: '{constructor_opts}'")
-    MlLogger.log_params(constructor_opts)
-    MlLogger.log_params({"schedule_name": schedule_name})
+    tracker.track_params(constructor_opts)
+    tracker.track_params({"schedule_name": schedule_name})
 
     scheduler = sched_constructor(optimizer, **constructor_opts)
     scheduler.opts = opts  # save the opts with the scheduler to use in load/save
