@@ -1,16 +1,15 @@
 from typing import Optional, Union, Tuple, List, Callable
 
-from torch.optim.lr_scheduler import _LRScheduler
-
 import sys
 import shutil
 import logging
-import dill
-import numpy
-import torch
-from tqdm import tqdm
 from pathlib import Path
 
+import dill
+import numpy
+from tqdm import tqdm
+import torch
+from torch.optim.lr_scheduler import _LRScheduler
 from torch.nn import MSELoss, Linear, Module, ModuleList, DataParallel
 import torch.nn.functional as F
 from torch.optim import Optimizer
@@ -20,7 +19,7 @@ from haystack.modeling.evaluation.eval import Evaluator
 from haystack.modeling.model.adaptive_model import AdaptiveModel
 from haystack.modeling.model.optimization import get_scheduler
 from haystack.modeling.utils import GracefulKiller
-from haystack.modeling.logger import MLFlowLogger as MlLogger
+from haystack.utils.experiment_tracking import Tracker as tracker
 
 try:
     from apex import amp
@@ -162,7 +161,7 @@ class Trainer:
                                Useful to achieve larger effective batch sizes that would not fit in GPU memory.
         :param local_rank: Local rank of process when distributed training via DDP is used.
         :param early_stopping: an initialized EarlyStopping object to control early stopping and saving of best models.
-        :param log_learning_rate: Whether to log learning rate to Mlflow
+        :param log_learning_rate: Whether to log learning rate to experiment tracker (e.g. Mlflow)
         :param log_loss_every: Log current train loss after this many train steps.
         :param checkpoint_on_sigterm: save a checkpoint for the Trainer when a SIGTERM signal is sent. The checkpoint
                can be used to resume training. It is useful in frameworks like AWS SageMaker with Spot instances where
@@ -378,9 +377,9 @@ class Trainer:
         loss = self.adjust_loss(loss)
         if self.global_step % self.log_loss_every == 0 and self.local_rank in [-1, 0]:
             if self.local_rank in [-1, 0]:
-                MlLogger.log_metrics({"Train_loss_total": float(loss.detach().cpu().numpy())}, step=self.global_step)
+                tracker.track_metrics({"Train_loss_total": float(loss.detach().cpu().numpy())}, step=self.global_step)
                 if self.log_learning_rate:
-                    MlLogger.log_metrics({"learning_rate": self.lr_schedule.get_last_lr()[0]}, step=self.global_step)
+                    tracker.track_metrics({"learning_rate": self.lr_schedule.get_last_lr()[0]}, step=self.global_step)
         if self.use_amp:
             with amp.scale_loss(loss, self.optimizer) as scaled_loss:
                 scaled_loss.backward()
@@ -407,7 +406,7 @@ class Trainer:
 
     def log_params(self):
         params = {"epochs": self.epochs, "n_gpu": self.n_gpu, "device": self.device}
-        MlLogger.log_params(params)
+        tracker.track_params(params)
 
     @classmethod
     def create_or_load_checkpoint(
@@ -661,7 +660,7 @@ class DistillationTrainer(Trainer):
         epochs: int,
         n_gpu: int,
         device: torch.device,
-        lr_schedule: Optional["_LRScheduler"] = None,
+        lr_schedule: Optional[_LRScheduler] = None,
         evaluate_every: int = 100,
         eval_report: bool = True,
         use_amp: Optional[str] = None,
@@ -701,7 +700,7 @@ class DistillationTrainer(Trainer):
                                Useful to achieve larger effective batch sizes that would not fit in GPU memory.
         :param local_rank: Local rank of process when distributed training via DDP is used.
         :param early_stopping: an initialized EarlyStopping object to control early stopping and saving of best models.
-        :param log_learning_rate: Whether to log learning rate to Mlflow
+        :param log_learning_rate: Whether to log learning rate to experiment tracker (e.g. Mlflow)
         :param log_loss_every: Log current train loss after this many train steps.
         :param checkpoint_on_sigterm: save a checkpoint for the Trainer when a SIGTERM signal is sent. The checkpoint
                can be used to resume training. It is useful in frameworks like AWS SageMaker with Spot instances where
@@ -806,7 +805,7 @@ class TinyBERTDistillationTrainer(Trainer):
         epochs: int,
         n_gpu: int,
         device: torch.device,
-        lr_schedule: Optional["_LRScheduler"] = None,
+        lr_schedule: Optional[_LRScheduler] = None,
         evaluate_every: int = 100,
         eval_report: bool = True,
         use_amp: Optional[str] = None,
@@ -843,7 +842,7 @@ class TinyBERTDistillationTrainer(Trainer):
                                Useful to achieve larger effective batch sizes that would not fit in GPU memory.
         :param local_rank: Local rank of process when distributed training via DDP is used.
         :param early_stopping: an initialized EarlyStopping object to control early stopping and saving of best models.
-        :param log_learning_rate: Whether to log learning rate to Mlflow
+        :param log_learning_rate: Whether to log learning rate to experiment tracker (e.g. Mlflow)
         :param log_loss_every: Log current train loss after this many train steps.
         :param checkpoint_on_sigterm: save a checkpoint for the Trainer when a SIGTERM signal is sent. The checkpoint
                can be used to resume training. It is useful in frameworks like AWS SageMaker with Spot instances where
