@@ -1,11 +1,9 @@
+from typing import Dict, List, Optional
+
 import logging
 from collections.abc import Callable
-from enum import Enum
-from typing import Any, Dict, List, Optional
-
 import numpy
 import torch
-from haystack.modeling.utils import initialize_device_settings
 from transformers import (
     RagTokenizer,
     RagTokenForGeneration,
@@ -15,9 +13,10 @@ from transformers import (
     BatchEncoding,
 )
 
-from haystack.schema import Answer, Document
+from haystack.schema import Document
 from haystack.nodes.answer_generator.base import BaseGenerator
 from haystack.nodes.retriever.dense import DensePassageRetriever
+from haystack.modeling.utils import initialize_device_settings
 
 
 logger = logging.getLogger(__name__)
