@@ -28,7 +28,7 @@ class TransformersDocumentClassifier(BaseDocumentClassifier):
      **Usage example at query time:**
      ```python
     |    ...
-    |    retriever = ElasticsearchRetriever(document_store=document_store)
+    |    retriever = BM25Retriever(document_store=document_store)
     |    document_classifier = TransformersDocumentClassifier(model_name_or_path="bhadresh-savani/distilbert-base-uncased-emotion")
     |    p = Pipeline()
     |    p.add_node(component=retriever, name="Retriever", inputs=["Query"])
