@@ -5,13 +5,18 @@ try:
 except ImportError:
     from typing_extensions import Literal  # type: ignore
 
-import requests
 import json
-from pathlib import Path
 import copy
 import logging
+from pathlib import Path
+
+import requests
+import pandas as pd
+
+from haystack.nodes.file_converter.base import BaseConverter
+from haystack.schema import Document
+from haystack.errors import HaystackError
 
-from haystack.nodes.file_converter import BaseConverter
 
 logger = logging.getLogger(__name__)
 
@@ -35,6 +40,7 @@ class ParsrConverter(BaseConverter):
         remove_page_footers: bool = False,
         remove_table_of_contents: bool = False,
         valid_languages: Optional[List[str]] = None,
+        id_hash_keys: Optional[List[str]] = None,
     ):
         """
         :param parsr_url: URL endpoint to Parsr"s REST API.
@@ -54,8 +60,12 @@ class ParsrConverter(BaseConverter):
                                 This option can be used to add test for encoding errors. If the extracted text is
                                 not one of the valid languages, then it might likely be encoding error resulting
                                 in garbled text.
+        :param id_hash_keys: Generate the document id from a custom list of strings that refer to the document's
+            attributes. If you want to ensure you don't have duplicate documents in your DocumentStore but texts are
+            not unique, you can modify the metadata and pass e.g. `"meta"` to this field (e.g. [`"content"`, `"meta"`]).
+            In this case the id will be generated by using the content and the defined metadata.
         """
-        super().__init__(valid_languages=valid_languages)
+        super().__init__(valid_languages=valid_languages, id_hash_keys=id_hash_keys)
 
         try:
             ping = requests.get(parsr_url)
@@ -89,7 +99,8 @@ class ParsrConverter(BaseConverter):
         remove_numeric_tables: Optional[bool] = None,
         valid_languages: Optional[List[str]] = None,
         encoding: Optional[str] = "utf-8",
-    ) -> List[Dict[str, Any]]:
+        id_hash_keys: Optional[List[str]] = None,
+    ) -> List[Document]:
         """
         Extract text and tables from a PDF or DOCX using the open-source Parsr tool.
 
@@ -102,17 +113,24 @@ class ParsrConverter(BaseConverter):
                                 This option can be used to add test for encoding errors. If the extracted text is
                                 not one of the valid languages, then it might likely be encoding error resulting
                                 in garbled text.
-        :param encoding: Not applicable..
+        :param encoding: Not applicable.
+        :param id_hash_keys: Generate the document id from a custom list of strings that refer to the document's
+            attributes. If you want to ensure you don't have duplicate documents in your DocumentStore but texts are
+            not unique, you can modify the metadata and pass e.g. `"meta"` to this field (e.g. [`"content"`, `"meta"`]).
+            In this case the id will be generated by using the content and the defined metadata.
         """
         if valid_languages is None:
             valid_languages = self.valid_languages
 
+        if id_hash_keys is None:
+            id_hash_keys = self.id_hash_keys
+
         with open(file_path, "rb") as pdf_file:
             # Send file to Parsr
             send_response = requests.post(
                 url=f"{self.parsr_url}/api/v1/document",
-                files={
-                    "file": (file_path, pdf_file, "application/pdf"),
+                files={  # type: ignore
+                    "file": (str(file_path), pdf_file, "application/pdf"),
                     "config": ("config", json.dumps(self.config), "application/json"),
                 },
             )
@@ -138,18 +156,27 @@ class ParsrConverter(BaseConverter):
                             text += f"{current_paragraph}\n\n"
 
                     elif element["type"] == "table":
-                        table = self._convert_table_element(element, parsr_output["pages"], page_idx, elem_idx, meta)
+                        table = self._convert_table_element(
+                            element, parsr_output["pages"], page_idx, elem_idx, meta, id_hash_keys
+                        )
                         tables.append(table)
 
         if valid_languages:
-            file_text = text + " ".join([cell for table in tables for row in table["content"] for cell in row])
+            file_text = text
+            for table in tables:
+                # Mainly needed for type checking
+                if not isinstance(table.content, pd.DataFrame):
+                    raise HaystackError("Document's content field must be of type 'pd.DataFrame'.")
+                for _, row in table.content.iterrows():
+                    for _, cell in row.items():
+                        file_text += f" {cell}"
             if not self.validate_language(file_text, valid_languages):
                 logger.warning(
                     f"The language for {file_path} is not one of {valid_languages}. The file may not have "
                     f"been decoded in the correct text format."
                 )
 
-        docs = tables + [{"content": text.strip(), "content_type": "text", "meta": meta}]
+        docs = tables + [Document(content=text.strip(), meta=meta, id_hash_keys=id_hash_keys)]
         return docs
 
     def _get_paragraph_string(self, paragraph: Dict[str, Any]) -> str:
@@ -185,7 +212,8 @@ class ParsrConverter(BaseConverter):
         page_idx: int,
         elem_idx: int,
         meta: Optional[Dict[str, str]] = None,
-    ) -> Dict[str, Any]:
+        id_hash_keys: Optional[List[str]] = None,
+    ) -> Document:
 
         row_idx_start = 0
         caption = ""
@@ -251,4 +279,5 @@ class ParsrConverter(BaseConverter):
         else:
             table_meta = {"preceding_context": preceding_context, "following_context": following_context}
 
-        return {"content": table_list, "content_type": "table", "meta": table_meta}
+        table_df = pd.DataFrame(columns=table_list[0], data=table_list[1:])
+        return Document(content=table_df, content_type="table", meta=table_meta, id_hash_keys=id_hash_keys)
