@@ -4,12 +4,15 @@ from copy import deepcopy
 from functools import partial, reduce
 from itertools import chain
 from typing import List, Optional, Generator, Set, Union
+import warnings
 
 import nltk
 from more_itertools import windowed
 from tqdm import tqdm
 
-from haystack.nodes.preprocessor import BasePreProcessor
+from haystack.nodes.preprocessor.base import BasePreProcessor
+from haystack.errors import HaystackError
+from haystack.schema import Document
 
 
 logger = logging.getLogger(__name__)
@@ -49,6 +52,7 @@ class PreProcessor(BasePreProcessor):
         split_overlap: int = 0,
         split_respect_sentence_boundary: bool = True,
         language: str = "en",
+        id_hash_keys: Optional[List[str]] = None,
     ):
         """
         :param clean_header_footer: Use heuristic to remove footers and headers across different pages by searching
@@ -71,6 +75,10 @@ class PreProcessor(BasePreProcessor):
                                                 to True, the individual split will always have complete sentences &
                                                 the number of words will be <= split_length.
         :param language: The language used by "nltk.tokenize.sent_tokenize" in iso639 format. Available options: "en", "es", "de", "fr" & many more.
+        :param id_hash_keys: Generate the document id from a custom list of strings that refer to the document's
+            attributes. If you want to ensure you don't have duplicate documents in your DocumentStore but texts are
+            not unique, you can modify the metadata and pass e.g. `"meta"` to this field (e.g. [`"content"`, `"meta"`]).
+            In this case the id will be generated by using the content and the defined metadata.
         """
         super().__init__()
 
@@ -89,10 +97,11 @@ class PreProcessor(BasePreProcessor):
         self.split_respect_sentence_boundary = split_respect_sentence_boundary
         self.language = iso639_to_nltk.get(language, language)
         self.print_log: Set[str] = set()
+        self.id_hash_keys = id_hash_keys
 
     def process(
         self,
-        documents: Union[dict, List[dict]],
+        documents: Union[dict, Document, List[Union[dict, Document]]],
         clean_whitespace: Optional[bool] = None,
         clean_header_footer: Optional[bool] = None,
         clean_empty_lines: Optional[bool] = None,
@@ -101,11 +110,19 @@ class PreProcessor(BasePreProcessor):
         split_length: Optional[int] = None,
         split_overlap: Optional[int] = None,
         split_respect_sentence_boundary: Optional[bool] = None,
-    ) -> List[dict]:
+        id_hash_keys: Optional[List[str]] = None,
+    ) -> List[Document]:
 
         """
         Perform document cleaning and splitting. Can take a single document or a list of documents as input and returns a list of documents.
         """
+        if not isinstance(documents, list):
+            warnings.warn(
+                "Using a single Document as argument to the 'documents' parameter is deprecated. Use a list "
+                "of (a single) Document instead.",
+                DeprecationWarning,
+                2,
+            )
 
         kwargs = {
             "clean_whitespace": clean_whitespace,
@@ -118,12 +135,15 @@ class PreProcessor(BasePreProcessor):
             "split_respect_sentence_boundary": split_respect_sentence_boundary,
         }
 
+        if id_hash_keys is None:
+            id_hash_keys = self.id_hash_keys
+
         ret = []
 
-        if isinstance(documents, dict):
-            ret = self._process_single(document=documents, **kwargs)  # type: ignore
+        if isinstance(documents, (Document, dict)):
+            ret = self._process_single(document=documents, id_hash_keys=id_hash_keys, **kwargs)  # type: ignore
         elif isinstance(documents, list):
-            ret = self._process_batch(documents=list(documents), **kwargs)
+            ret = self._process_batch(documents=list(documents), id_hash_keys=id_hash_keys, **kwargs)
 
         else:
             raise Exception("documents provided to PreProcessor.prepreprocess() is not of type list nor Document")
@@ -132,7 +152,7 @@ class PreProcessor(BasePreProcessor):
 
     def _process_single(
         self,
-        document,
+        document: Union[dict, Document],
         clean_whitespace: Optional[bool] = None,
         clean_header_footer: Optional[bool] = None,
         clean_empty_lines: Optional[bool] = None,
@@ -141,7 +161,8 @@ class PreProcessor(BasePreProcessor):
         split_length: Optional[int] = None,
         split_overlap: Optional[int] = None,
         split_respect_sentence_boundary: Optional[bool] = None,
-    ) -> List[dict]:
+        id_hash_keys: Optional[List[str]] = None,
+    ) -> List[Document]:
 
         if clean_whitespace is None:
             clean_whitespace = self.clean_whitespace
@@ -166,6 +187,7 @@ class PreProcessor(BasePreProcessor):
             clean_header_footer=clean_header_footer,
             clean_empty_lines=clean_empty_lines,
             remove_substrings=remove_substrings,
+            id_hash_keys=id_hash_keys,
         )
         split_documents = self.split(
             document=cleaned_document,
@@ -173,26 +195,41 @@ class PreProcessor(BasePreProcessor):
             split_length=split_length,
             split_overlap=split_overlap,
             split_respect_sentence_boundary=split_respect_sentence_boundary,
+            id_hash_keys=id_hash_keys,
         )
         return split_documents
 
-    def _process_batch(self, documents: List[dict], **kwargs) -> List[dict]:
-        nested_docs = [self._process_single(d, **kwargs) for d in tqdm(documents, unit="docs")]
+    def _process_batch(
+        self, documents: List[Union[dict, Document]], id_hash_keys: Optional[List[str]] = None, **kwargs
+    ) -> List[Document]:
+        nested_docs = [
+            self._process_single(d, id_hash_keys=id_hash_keys, **kwargs) for d in tqdm(documents, unit="docs")
+        ]
         return [d for x in nested_docs for d in x]
 
     def clean(
         self,
-        document: dict,
+        document: Union[dict, Document],
         clean_whitespace: bool,
         clean_header_footer: bool,
         clean_empty_lines: bool,
         remove_substrings: List[str],
-    ) -> dict:
+        id_hash_keys: Optional[List[str]] = None,
+    ) -> Document:
         """
         Perform document cleaning on a single document and return a single document. This method will deal with whitespaces, headers, footers
         and empty lines. Its exact functionality is defined by the parameters passed into PreProcessor.__init__().
         """
-        text = document["content"]
+        if id_hash_keys is None:
+            id_hash_keys = self.id_hash_keys
+
+        if isinstance(document, dict):
+            document = Document.from_dict(document, id_hash_keys=id_hash_keys)
+
+        # Mainly needed for type checking
+        if not isinstance(document, Document):
+            raise HaystackError("Document must not be of type 'dict' but of type 'Document'.")
+        text = document.content
         if clean_header_footer:
             text = self._find_and_remove_header_footer(
                 text, n_chars=300, n_first_pages_to_ignore=1, n_last_pages_to_ignore=1
@@ -213,23 +250,32 @@ class PreProcessor(BasePreProcessor):
         for substring in remove_substrings:
             text = text.replace(substring, "")
 
-        if text != document["content"]:
+        if text != document.content:
             document = deepcopy(document)
-            document["content"] = text
+            document.content = text
 
         return document
 
     def split(
         self,
-        document: dict,
+        document: Union[dict, Document],
         split_by: str,
         split_length: int,
         split_overlap: int,
         split_respect_sentence_boundary: bool,
-    ) -> List[dict]:
+        id_hash_keys: Optional[List[str]] = None,
+    ) -> List[Document]:
         """Perform document splitting on a single document. This method can split on different units, at different lengths,
         with different strides. It can also respect sentence boundaries. Its exact functionality is defined by
         the parameters passed into PreProcessor.__init__(). Takes a single document as input and returns a list of documents."""
+        if id_hash_keys is None:
+            id_hash_keys = self.id_hash_keys
+
+        if isinstance(document, dict):
+            document = Document.from_dict(document, id_hash_keys=id_hash_keys)
+        # Mainly needed for type checking
+        if not isinstance(document, Document):
+            raise HaystackError("Document must not be of type 'dict' but of type 'Document'.")
 
         if not split_by:
             return [document]
@@ -240,7 +286,7 @@ class PreProcessor(BasePreProcessor):
         if split_respect_sentence_boundary and split_by != "word":
             raise NotImplementedError("'split_respect_sentence_boundary=True' is only compatible with split_by='word'.")
 
-        text = document["content"]
+        text = document.content
 
         if split_respect_sentence_boundary and split_by == "word":
             # split by words ensuring no sub sentence splits
@@ -310,11 +356,8 @@ class PreProcessor(BasePreProcessor):
         # create new document dicts for each text split
         documents = []
         for i, txt in enumerate(text_splits):
-            doc = deepcopy(document)
-            doc["content"] = txt
-            if "meta" not in doc.keys() or doc["meta"] is None:
-                doc["meta"] = {}
-            doc["meta"]["_split_id"] = i
+            doc = Document(content=txt, meta=deepcopy(document.meta) or {}, id_hash_keys=id_hash_keys)
+            doc.meta["_split_id"] = i
             documents.append(doc)
 
         return documents
