@@ -1,12 +1,13 @@
 from typing import List, Optional, Sequence, Dict, Tuple
 
-import numpy as np
-from scipy.special import expit
 from abc import abstractmethod
 from copy import deepcopy
 from functools import wraps
 from time import perf_counter
 
+import numpy as np
+from scipy.special import expit
+
 from haystack.schema import Document, Answer, Span, MultiLabel
 from haystack.nodes.base import BaseComponent
 
@@ -91,7 +92,7 @@ class BaseReader(BaseComponent):
 
         # run evaluation with labels as node inputs
         if add_isolated_node_eval and labels is not None:
-            relevant_documents = [label.document for label in labels.labels]
+            relevant_documents = {label.document.id: label.document for label in labels.labels}.values()
             results_label_input = predict(query=query, documents=relevant_documents, top_k=top_k)
 
             # Add corresponding document_name and more meta data, if an answer contains the document_id
