@@ -21,6 +21,15 @@ from haystack.schema import Document, Answer, Span
 from haystack.nodes.reader.base import BaseReader
 from haystack.modeling.utils import initialize_device_settings
 
+torch_scatter_installed = True
+torch_scatter_wrong_version = False
+try:
+    import torch_scatter  # pylint: disable=unused-import
+except ImportError:
+    torch_scatter_installed = False
+except OSError:
+    torch_scatter_wrong_version = True
+
 
 logger = logging.getLogger(__name__)
 
@@ -95,6 +104,15 @@ class TableReader(BaseReader):
                             query + table exceed max_seq_len, the table will be truncated by removing rows until the
                             input size fits the model.
         """
+        if not torch_scatter_installed:
+            raise ImportError(
+                "Please install torch_scatter to use TableReader. You can follow the instructions here: https://github.com/rusty1s/pytorch_scatter"
+            )
+        if torch_scatter_wrong_version:
+            raise ImportError(
+                "torch_scatter could not be loaded. This could be caused by a mismatch between your cuda version and the one used by torch_scatter."
+                "Please try to reinstall torch-scatter. You can follow the instructions here: https://github.com/rusty1s/pytorch_scatter"
+            )
         super().__init__()
 
         self.devices, _ = initialize_device_settings(use_cuda=use_gpu, multi_gpu=False)
@@ -137,10 +155,15 @@ class TableReader(BaseReader):
         no_answer_score = 1.0
         for document in documents:
             if document.content_type != "table":
-                logger.warning(f"Skipping document with id {document.id} in TableReader, as it is not of type table.")
+                logger.warning(f"Skipping document with id '{document.id}' in TableReader as it is not of type table.")
                 continue
 
             table: pd.DataFrame = document.content
+            if table.shape[0] == 0:
+                logger.warning(
+                    f"Skipping document with id '{document.id}' in TableReader as it does not contain any rows."
+                )
+                continue
             # Tokenize query and current table
             inputs = self.tokenizer(
                 table=table, queries=query, max_length=self.max_seq_len, return_tensors="pt", truncation=True
@@ -370,7 +393,7 @@ class TableReader(BaseReader):
                 else:
                     raise KeyError("unknown aggregator")
 
-            return f"{answer_value}{' ' + unit if unit else ''}"
+                return f"{answer_value}{' ' + unit if unit else ''}"
 
         except KeyError as e:
             if "unknown aggregator" in str(e):
@@ -525,10 +548,15 @@ class RCIReader(BaseReader):
         answers = []
         for document in documents:
             if document.content_type != "table":
-                logger.warning(f"Skipping document with id {document.id} in RCIReader, as it is not of type table.")
+                logger.warning(f"Skipping document with id '{document.id}' in RCIReader as it is not of type table.")
                 continue
 
             table: pd.DataFrame = document.content
+            if table.shape[0] == 0:
+                logger.warning(
+                    f"Skipping document with id '{document.id}' in RCIReader as it does not contain any rows."
+                )
+                continue
             table = table.astype(str)
             # Create row and column representations
             row_reps, column_reps = self._create_row_column_representations(table)
