@@ -1,4 +1,10 @@
 from haystack.nodes.retriever.base import BaseRetriever
 from haystack.nodes.retriever.dense import DensePassageRetriever, EmbeddingRetriever, TableTextRetriever
-from haystack.nodes.retriever.sparse import ElasticsearchRetriever, ElasticsearchFilterOnlyRetriever, TfidfRetriever
+from haystack.nodes.retriever.sparse import (
+    BM25Retriever,
+    ElasticsearchRetriever,
+    ElasticsearchFilterOnlyRetriever,
+    FilterRetriever,
+    TfidfRetriever,
+)
 from haystack.nodes.retriever.text2sparql import Text2SparqlRetriever
