@@ -1,12 +1,13 @@
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, Union
 
 import logging
 from abc import abstractmethod
 from time import perf_counter
 from functools import wraps
-from tqdm import tqdm
 from copy import deepcopy
 
+from tqdm import tqdm
+
 from haystack.schema import Document, MultiLabel
 from haystack.errors import HaystackError
 from haystack.nodes.base import BaseComponent
@@ -58,6 +59,7 @@ class BaseRetriever(BaseComponent):
         top_k: Optional[int] = None,
         index: str = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = None,
     ) -> List[Document]:
         """
         Scan through documents in DocumentStore and return a small number documents
@@ -68,6 +70,9 @@ class BaseRetriever(BaseComponent):
         :param top_k: How many documents to return per query.
         :param index: The name of the index in the DocumentStore from which to retrieve documents
         :param headers: Custom HTTP headers to pass to document store client if supported (e.g. {'Authorization': 'Basic YWRtaW46cm9vdA=='} for basic authentication)
+        :param scale_score: Whether to scale the similarity score to the unit interval (range of [0,1]).
+                            If true (default) similarity scores (e.g. cosine or dot_product) which naturally have a different value range will be scaled to a range of [0,1], where 1 means extremely relevant.
+                            Otherwise raw similarity scores (e.g. cosine or dot_product) will be used.
         """
         pass
 
@@ -239,6 +244,7 @@ class BaseRetriever(BaseComponent):
         documents: Optional[List[dict]] = None,
         index: Optional[str] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = None,
     ):
         if root_node == "Query":
             if not query:
@@ -247,7 +253,9 @@ class BaseRetriever(BaseComponent):
                 )
             self.query_count += 1
             run_query_timed = self.timing(self.run_query, "query_time")
-            output, stream = run_query_timed(query=query, filters=filters, top_k=top_k, index=index, headers=headers)
+            output, stream = run_query_timed(
+                query=query, filters=filters, top_k=top_k, index=index, headers=headers, scale_score=scale_score
+            )
         elif root_node == "File":
             self.index_count += len(documents)  # type: ignore
             run_indexing = self.timing(self.run_indexing, "index_time")
@@ -263,21 +271,24 @@ class BaseRetriever(BaseComponent):
         top_k: Optional[int] = None,
         index: Optional[str] = None,
         headers: Optional[Dict[str, str]] = None,
+        scale_score: bool = None,
     ):
-        documents = self.retrieve(query=query, filters=filters, top_k=top_k, index=index, headers=headers)
+        documents = self.retrieve(
+            query=query, filters=filters, top_k=top_k, index=index, headers=headers, scale_score=scale_score
+        )
         document_ids = [doc.id for doc in documents]
         logger.debug(f"Retrieved documents with IDs: {document_ids}")
         output = {"documents": documents}
 
         return output, "output_1"
 
-    def run_indexing(self, documents: List[dict]):
+    def run_indexing(self, documents: List[Union[dict, Document]]):
         if self.__class__.__name__ in ["DensePassageRetriever", "EmbeddingRetriever"]:
             documents = deepcopy(documents)
-            document_objects = [Document.from_dict(doc) for doc in documents]
+            document_objects = [Document.from_dict(doc) if isinstance(doc, dict) else doc for doc in documents]
             embeddings = self.embed_documents(document_objects)  # type: ignore
-            for doc, emb in zip(documents, embeddings):
-                doc["embedding"] = emb
+            for doc, emb in zip(document_objects, embeddings):
+                doc.embedding = emb
         output = {"documents": documents}
         return output, "output_1"
 
