@@ -4,7 +4,7 @@ from typing import Any, Dict, List, Optional, Union
 from transformers import AutoModelForSeq2SeqLM, AutoTokenizer
 
 from haystack.schema import Document, Answer
-from haystack.nodes.translator import BaseTranslator
+from haystack.nodes.translator.base import BaseTranslator
 from haystack.modeling.utils import initialize_device_settings
 
 
