@@ -1,6 +1,6 @@
 import pytest
 
-from haystack.nodes.retriever.sparse import ElasticsearchRetriever
+from haystack.nodes.retriever.sparse import BM25Retriever
 from haystack.nodes.reader import FARMReader
 from haystack.pipelines import Pipeline
 
@@ -10,7 +10,7 @@ from haystack.nodes.extractor import EntityExtractor, simplify_ner_for_qa
 @pytest.mark.parametrize("document_store_with_docs", ["elasticsearch"], indirect=True)
 def test_extractor(document_store_with_docs):
 
-    es_retriever = ElasticsearchRetriever(document_store=document_store_with_docs)
+    es_retriever = BM25Retriever(document_store=document_store_with_docs)
     ner = EntityExtractor()
     reader = FARMReader(model_name_or_path="deepset/roberta-base-squad2", num_processes=0)
 
@@ -30,7 +30,7 @@ def test_extractor(document_store_with_docs):
 @pytest.mark.parametrize("document_store_with_docs", ["elasticsearch"], indirect=True)
 def test_extractor_output_simplifier(document_store_with_docs):
 
-    es_retriever = ElasticsearchRetriever(document_store=document_store_with_docs)
+    es_retriever = BM25Retriever(document_store=document_store_with_docs)
     ner = EntityExtractor()
     reader = FARMReader(model_name_or_path="deepset/roberta-base-squad2", num_processes=0)
 
