@@ -23,7 +23,9 @@ def shutdown_ray():
 @pytest.mark.parametrize("document_store_with_docs", ["elasticsearch"], indirect=True)
 def test_load_pipeline(document_store_with_docs):
     pipeline = RayPipeline.load_from_yaml(
-        SAMPLES_PATH / "pipeline" / "test_ray_pipeline.yaml", pipeline_name="ray_query_pipeline", num_cpus=8
+        SAMPLES_PATH / "pipeline" / "test_ray_pipeline.yaml",
+        pipeline_name="ray_query_pipeline",
+        ray_args={"num_cpus": 8},
     )
     prediction = pipeline.run(query="Who lives in Berlin?", params={"Retriever": {"top_k": 10}, "Reader": {"top_k": 3}})
 
