@@ -1,7 +1,9 @@
+import logging
 import time
 
 import numpy as np
 import pandas as pd
+from haystack.document_stores.memory import InMemoryDocumentStore
 import pytest
 from pathlib import Path
 from elasticsearch import Elasticsearch
@@ -11,8 +13,8 @@ from haystack.schema import Document
 from haystack.document_stores.elasticsearch import ElasticsearchDocumentStore
 from haystack.document_stores.faiss import FAISSDocumentStore
 from haystack.document_stores import MilvusDocumentStore
-from haystack.nodes.retriever.dense import DensePassageRetriever, TableTextRetriever
-from haystack.nodes.retriever.sparse import ElasticsearchRetriever, ElasticsearchFilterOnlyRetriever, TfidfRetriever
+from haystack.nodes.retriever.dense import DensePassageRetriever, EmbeddingRetriever, TableTextRetriever
+from haystack.nodes.retriever.sparse import BM25Retriever, FilterRetriever, TfidfRetriever
 from transformers import DPRContextEncoderTokenizerFast, DPRQuestionEncoderTokenizerFast
 
 from .conftest import SAMPLES_PATH
@@ -68,7 +70,7 @@ def docs():
     indirect=True,
 )
 def test_retrieval(retriever_with_docs, document_store_with_docs):
-    if not isinstance(retriever_with_docs, (ElasticsearchRetriever, ElasticsearchFilterOnlyRetriever, TfidfRetriever)):
+    if not isinstance(retriever_with_docs, (BM25Retriever, FilterRetriever, TfidfRetriever)):
         document_store_with_docs.update_embeddings(retriever_with_docs)
 
     # test without filters
@@ -82,7 +84,7 @@ def test_retrieval(retriever_with_docs, document_store_with_docs):
         retriever_with_docs, TfidfRetriever
     ):
         # single filter
-        result = retriever_with_docs.retrieve(query="godzilla", filters={"name": ["filename3"]}, top_k=5)
+        result = retriever_with_docs.retrieve(query="Christelle", filters={"name": ["filename3"]}, top_k=5)
         assert len(result) == 1
         assert type(result[0]) == Document
         assert result[0].content == "My name is Christelle and I live in Paris"
@@ -90,14 +92,14 @@ def test_retrieval(retriever_with_docs, document_store_with_docs):
 
         # multiple filters
         result = retriever_with_docs.retrieve(
-            query="godzilla", filters={"name": ["filename2"], "meta_field": ["test2", "test3"]}, top_k=5
+            query="Paul", filters={"name": ["filename2"], "meta_field": ["test2", "test3"]}, top_k=5
         )
         assert len(result) == 1
         assert type(result[0]) == Document
         assert result[0].meta["name"] == "filename2"
 
         result = retriever_with_docs.retrieve(
-            query="godzilla", filters={"name": ["filename1"], "meta_field": ["test2", "test3"]}, top_k=5
+            query="Carla", filters={"name": ["filename1"], "meta_field": ["test2", "test3"]}, top_k=5
         )
         assert len(result) == 0
 
@@ -119,11 +121,11 @@ def test_elasticsearch_custom_query():
     document_store.write_documents(documents)
 
     # test custom "terms" query
-    retriever = ElasticsearchRetriever(
+    retriever = BM25Retriever(
         document_store=document_store,
         custom_query="""
             {
-                "size": 10, 
+                "size": 10,
                 "query": {
                     "bool": {
                         "should": [{
@@ -134,11 +136,11 @@ def test_elasticsearch_custom_query():
     assert len(results) == 4
 
     # test custom "term" query
-    retriever = ElasticsearchRetriever(
+    retriever = BM25Retriever(
         document_store=document_store,
         custom_query="""
                 {
-                    "size": 10, 
+                    "size": 10,
                     "query": {
                         "bool": {
                             "should": [{
@@ -190,11 +192,7 @@ def test_retribert_embedding(document_store, retriever, docs):
     if isinstance(document_store, WeaviateDocumentStore):
         # Weaviate sets the embedding dimension to 768 as soon as it is initialized.
         # We need 128 here and therefore initialize a new WeaviateDocumentStore.
-        document_store = WeaviateDocumentStore(
-            weaviate_url="http://localhost:8080", index="haystack_test", embedding_dim=128
-        )
-        document_store.weaviate_client.schema.delete_all()
-        document_store._create_schema_and_index_if_not_exist()
+        document_store = WeaviateDocumentStore(index="haystack_test", embedding_dim=128, recreate_index=True)
     document_store.return_embedding = True
     document_store.write_documents(docs)
     document_store.update_embeddings(retriever=retriever)
@@ -399,7 +397,7 @@ def test_elasticsearch_highlight():
     document_store.write_documents(documents)
 
     # Enabled highlighting on "title"&"content" field only using custom query
-    retriever_1 = ElasticsearchRetriever(
+    retriever_1 = BM25Retriever(
         document_store=document_store,
         custom_query="""{
             "size": 20,
@@ -441,7 +439,7 @@ def test_elasticsearch_highlight():
     assert results[0].meta["highlighted"]["content"] == ["The **green**", "**tea** plant", "range of **healthy**"]
 
     # Enabled highlighting on "title" field only using custom query
-    retriever_2 = ElasticsearchRetriever(
+    retriever_2 = BM25Retriever(
         document_store=document_store,
         custom_query="""{
             "size": 20,
@@ -479,3 +477,109 @@ def test_elasticsearch_highlight():
 
     assert len(results[0].meta["highlighted"]) == 1
     assert results[0].meta["highlighted"]["title"] == ["**Green**", "**tea** components"]
+
+
+def test_elasticsearch_filter_must_not_increase_results():
+    index = "filter_must_not_increase_results"
+    client = Elasticsearch()
+    client.indices.delete(index=index, ignore=[404])
+    documents = [
+        {
+            "content": "The green tea plant contains a range of healthy compounds that make it into the final drink",
+            "meta": {"content_type": "text"},
+            "id": "1",
+        },
+        {
+            "content": "Green tea contains a catechin called epigallocatechin-3-gallate (EGCG).",
+            "meta": {"content_type": "text"},
+            "id": "2",
+        },
+        {
+            "content": "Green tea also has small amounts of minerals that can benefit your health.",
+            "meta": {"content_type": "text"},
+            "id": "3",
+        },
+        {
+            "content": "Green tea does more than just keep you alert, it may also help boost brain function.",
+            "meta": {"content_type": "text"},
+            "id": "4",
+        },
+    ]
+    doc_store = ElasticsearchDocumentStore(index=index)
+    doc_store.write_documents(documents)
+    results_wo_filter = doc_store.query(query="drink")
+    assert len(results_wo_filter) == 1
+    results_w_filter = doc_store.query(query="drink", filters={"content_type": "text"})
+    assert len(results_w_filter) == 1
+    doc_store.delete_index(index)
+
+
+def test_elasticsearch_all_terms_must_match():
+    index = "all_terms_must_match"
+    client = Elasticsearch()
+    client.indices.delete(index=index, ignore=[404])
+    documents = [
+        {
+            "content": "The green tea plant contains a range of healthy compounds that make it into the final drink",
+            "meta": {"content_type": "text"},
+            "id": "1",
+        },
+        {
+            "content": "Green tea contains a catechin called epigallocatechin-3-gallate (EGCG).",
+            "meta": {"content_type": "text"},
+            "id": "2",
+        },
+        {
+            "content": "Green tea also has small amounts of minerals that can benefit your health.",
+            "meta": {"content_type": "text"},
+            "id": "3",
+        },
+        {
+            "content": "Green tea does more than just keep you alert, it may also help boost brain function.",
+            "meta": {"content_type": "text"},
+            "id": "4",
+        },
+    ]
+    doc_store = ElasticsearchDocumentStore(index=index)
+    doc_store.write_documents(documents)
+    results_wo_all_terms_must_match = doc_store.query(query="drink green tea")
+    assert len(results_wo_all_terms_must_match) == 4
+    results_w_all_terms_must_match = doc_store.query(query="drink green tea", all_terms_must_match=True)
+    assert len(results_w_all_terms_must_match) == 1
+    doc_store.delete_index(index)
+
+
+def test_embeddings_encoder_of_embedding_retriever_should_warn_about_model_format(caplog):
+    document_store = InMemoryDocumentStore()
+
+    with caplog.at_level(logging.WARNING):
+        EmbeddingRetriever(
+            document_store=document_store, embedding_model="sentence-transformers/paraphrase-multilingual-mpnet-base-v2"
+        )
+
+        assert (
+            "You may need to set 'model_format='sentence_transformers' to ensure correct loading of model."
+            in caplog.text
+        )
+
+
+@pytest.mark.parametrize("retriever", ["es_filter_only"], indirect=True)
+@pytest.mark.parametrize("document_store", ["elasticsearch"], indirect=True)
+def test_es_filter_only(document_store, retriever):
+    docs = [
+        Document(content="Doc1", meta={"f1": "0"}),
+        Document(content="Doc2", meta={"f1": "0"}),
+        Document(content="Doc3", meta={"f1": "0"}),
+        Document(content="Doc4", meta={"f1": "0"}),
+        Document(content="Doc5", meta={"f1": "0"}),
+        Document(content="Doc6", meta={"f1": "0"}),
+        Document(content="Doc7", meta={"f1": "1"}),
+        Document(content="Doc8", meta={"f1": "0"}),
+        Document(content="Doc9", meta={"f1": "0"}),
+        Document(content="Doc10", meta={"f1": "0"}),
+        Document(content="Doc11", meta={"f1": "0"}),
+        Document(content="Doc12", meta={"f1": "0"}),
+    ]
+    document_store.write_documents(docs)
+    retrieved_docs = retriever.retrieve(query="", filters={"f1": ["0"]})
+    assert len(retrieved_docs) == 11
