@@ -1,27 +1,45 @@
-from haystack.schema import Document, Label, Answer, Span
+from haystack.schema import Document, Label, Answer, Span, MultiLabel
 import pytest
 import numpy as np
 
 LABELS = [
-    Label(query="some",
-                   answer=Answer(answer="an answer",type="extractive", score=0.1, document_id="123", offsets_in_document=[Span(start=1, end=3)]),
-                   document=Document(content="some text", content_type="text"),
-                   is_correct_answer=True,
-                   is_correct_document=True,
-                   origin="user-feedback"),
-    Label(query="some",
-                   answer=Answer(answer="annother answer", type="extractive", score=0.1, document_id="123"),
-                   document=Document(content="some text", content_type="text"),
-                   is_correct_answer = True,
-                   is_correct_document = True,
-                   origin = "user-feedback"),
-
-    Label(query="some",
-                   answer=Answer(answer="an answer",type="extractive", score=0.1, document_id="123", offsets_in_document=[Span(start=1, end=3)]),
-                   document=Document(content="some text", content_type="text"),
-                   is_correct_answer = True,
-                   is_correct_document = True,
-                   origin = "user-feedback")]
+    Label(
+        query="some",
+        answer=Answer(
+            answer="an answer",
+            type="extractive",
+            score=0.1,
+            document_id="123",
+            offsets_in_document=[Span(start=1, end=3)],
+        ),
+        document=Document(content="some text", content_type="text"),
+        is_correct_answer=True,
+        is_correct_document=True,
+        origin="user-feedback",
+    ),
+    Label(
+        query="some",
+        answer=Answer(answer="annother answer", type="extractive", score=0.1, document_id="123"),
+        document=Document(content="some text", content_type="text"),
+        is_correct_answer=True,
+        is_correct_document=True,
+        origin="user-feedback",
+    ),
+    Label(
+        query="some",
+        answer=Answer(
+            answer="an answer",
+            type="extractive",
+            score=0.1,
+            document_id="123",
+            offsets_in_document=[Span(start=1, end=3)],
+        ),
+        document=Document(content="some text", content_type="text"),
+        is_correct_answer=True,
+        is_correct_document=True,
+        origin="user-feedback",
+    ),
+]
 
 
 def test_no_answer_label():
@@ -59,7 +77,7 @@ def test_no_answer_label():
             document=Document(content="some", id="777"),
             no_answer=False,
             origin="gold-label",
-        )
+        ),
     ]
 
     assert labels[0].no_answer == True
@@ -74,10 +92,15 @@ def test_equal_label():
 
 
 def test_answer_to_json():
-    a = Answer(answer="an answer",type="extractive", score=0.1, context="abc",
-               offsets_in_document=[Span(start=1, end=10)],
-               offsets_in_context=[Span(start=3, end=5)],
-               document_id="123")
+    a = Answer(
+        answer="an answer",
+        type="extractive",
+        score=0.1,
+        context="abc",
+        offsets_in_document=[Span(start=1, end=10)],
+        offsets_in_context=[Span(start=3, end=5)],
+        document_id="123",
+    )
     j = a.to_json()
     assert type(j) == str
     assert len(j) > 30
@@ -87,10 +110,15 @@ def test_answer_to_json():
 
 
 def test_answer_to_dict():
-    a = Answer(answer="an answer",type="extractive", score=0.1, context="abc",
-               offsets_in_document=[Span(start=1, end=10)],
-               offsets_in_context=[Span(start=3, end=5)],
-               document_id="123")
+    a = Answer(
+        answer="an answer",
+        type="extractive",
+        score=0.1,
+        context="abc",
+        offsets_in_document=[Span(start=1, end=10)],
+        offsets_in_context=[Span(start=3, end=5)],
+        document_id="123",
+    )
     j = a.to_dict()
     assert type(j) == dict
     a_new = Answer.from_dict(j)
@@ -117,17 +145,22 @@ def test_label_to_dict():
     assert l_new == LABELS[0]
     assert l_new.answer.offsets_in_document[0].start == 1
 
+
 def test_doc_to_json():
     # With embedding
-    d = Document(content="some text", content_type="text", score=0.99988, meta={"name": "doc1"},
-                 embedding=np.random.rand(768).astype(np.float32))
+    d = Document(
+        content="some text",
+        content_type="text",
+        score=0.99988,
+        meta={"name": "doc1"},
+        embedding=np.random.rand(768).astype(np.float32),
+    )
     j0 = d.to_json()
     d_new = Document.from_json(j0)
     assert d == d_new
 
     # No embedding
-    d = Document(content="some text", content_type="text", score=0.99988, meta={"name": "doc1"},
-                 embedding=None)
+    d = Document(content="some text", content_type="text", score=0.99988, meta={"name": "doc1"}, embedding=None)
     j0 = d.to_json()
     d_new = Document.from_json(j0)
     assert d == d_new
@@ -138,6 +171,7 @@ def test_answer_postinit():
     assert a.meta == {}
     assert isinstance(a.offsets_in_document[0], Span)
 
+
 def test_generate_doc_id_using_text():
     text1 = "text1"
     text2 = "text2"
@@ -157,7 +191,7 @@ def test_generate_doc_id_using_custom_list():
     doc1_meta2_id_by_content = Document(content=text1, meta={"name": "doc2"}, id_hash_keys=["content"])
     assert doc1_meta1_id_by_content.id == doc1_meta2_id_by_content.id
 
-    doc1_meta1_id_by_content_and_meta = Document(content=text1, meta={"name": "doc1"}, id_hash_keys=["content","meta"])
+    doc1_meta1_id_by_content_and_meta = Document(content=text1, meta={"name": "doc1"}, id_hash_keys=["content", "meta"])
     doc1_meta2_id_by_content_and_meta = Document(content=text1, meta={"name": "doc2"}, id_hash_keys=["content", "meta"])
     assert doc1_meta1_id_by_content_and_meta.id != doc1_meta2_id_by_content_and_meta.id
 
@@ -165,6 +199,39 @@ def test_generate_doc_id_using_custom_list():
     doc3_text2 = Document(content=text2, meta={"name": "doc3"}, id_hash_keys=["content"])
     assert doc1_text1.id != doc3_text2.id
 
-    
     with pytest.raises(ValueError):
-        _ = Document(content=text1, meta={"name": "doc1"}, id_hash_keys=["content","non_existing_field"])
\ No newline at end of file
+        _ = Document(content=text1, meta={"name": "doc1"}, id_hash_keys=["content", "non_existing_field"])
+
+
+def test_aggregate_labels_with_labels():
+    label1_with_filter1 = Label(
+        query="question",
+        answer=Answer(answer="1"),
+        is_correct_answer=True,
+        is_correct_document=True,
+        document=Document(content="some", id="777"),
+        origin="gold-label",
+        filters={"name": ["filename1"]},
+    )
+    label2_with_filter1 = Label(
+        query="question",
+        answer=Answer(answer="2"),
+        is_correct_answer=True,
+        is_correct_document=True,
+        document=Document(content="some", id="777"),
+        origin="gold-label",
+        filters={"name": ["filename1"]},
+    )
+    label3_with_filter2 = Label(
+        query="question",
+        answer=Answer(answer="2"),
+        is_correct_answer=True,
+        is_correct_document=True,
+        document=Document(content="some", id="777"),
+        origin="gold-label",
+        filters={"name": ["filename2"]},
+    )
+    label = MultiLabel(labels=[label1_with_filter1, label2_with_filter1])
+    assert label.filters == {"name": ["filename1"]}
+    with pytest.raises(ValueError):
+        label = MultiLabel(labels=[label1_with_filter1, label3_with_filter2])
