@@ -2,16 +2,14 @@ import pytest
 
 from haystack.pipelines import TranslationWrapperPipeline, SearchSummarizationPipeline
 from haystack.nodes import DensePassageRetriever, EmbeddingRetriever
-from test_summarizer import SPLIT_DOCS
+from .test_summarizer import SPLIT_DOCS
 
 # Keeping few (retriever,document_store) combination to reduce test time
 @pytest.mark.slow
 @pytest.mark.elasticsearch
 @pytest.mark.summarizer
 @pytest.mark.parametrize(
-    "retriever,document_store",
-    [("embedding", "memory"), ("elasticsearch", "elasticsearch")],
-    indirect=True,
+    "retriever,document_store", [("embedding", "memory"), ("elasticsearch", "elasticsearch")], indirect=True
 )
 def test_summarization_pipeline_with_translator(
     document_store, retriever, summarizer, en_to_de_translator, de_to_en_translator
